@@ -42,7 +42,7 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   FILE* stream = fopen(path, mode);
   
   if (!stream) {
-    env->die(env, stack, "[System Error]fopen failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fopen failed:%s. $path is \"%s\". $mode is \"%s\"", env->strerror(env, stack, errno, 0), path, mode, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -74,7 +74,7 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = fdopen(fd, mode);
   if (!stream) {
-    env->die(env, stack, "[System Error]fdopen failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fdopen failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -98,7 +98,7 @@ int32_t SPVM__Sys__IO__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = fileno(stream);
   if (fd == -1) {
-    env->die(env, stack, "[System Error]fileno failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fileno failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -143,6 +143,13 @@ int32_t SPVM__Sys__IO__fread(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t read_length = fread(ptr + ptr_offset, size, nmemb, stream);
   
+  if (read_length < nmemb) {
+    if (ferror(stream)) {
+      env->die(env, stack, "[System Error]fread failed.", __func__, FILE_NAME, __LINE__);
+      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    }
+  }
+  
   stack[0].ival = read_length;
   
   return 0;
@@ -211,6 +218,13 @@ int32_t SPVM__Sys__IO__getc(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t ch = getc(stream);
   
+  if (ch == EOF) {
+    if (ferror(stream)) {
+      env->die(env, stack, "[System Error]getc failed.", __func__, FILE_NAME, __LINE__);
+      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    }
+  }
+  
   stack[0].ival = ch;
   
   return 0;
@@ -228,7 +242,7 @@ int32_t SPVM__Sys__IO__ungetc(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = ungetc(c, stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]ungetc failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]ungetc failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -311,9 +325,16 @@ int32_t SPVM__Sys__IO__fwrite(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  int32_t fwrite_length = fwrite(ptr + ptr_offset, size, nmemb, stream);
+  int32_t write_length = fwrite(ptr + ptr_offset, size, nmemb, stream);
   
-  stack[0].ival = fwrite_length;
+  if (write_length < nmemb) {
+    if (ferror(stream)) {
+      env->die(env, stack, "[System Error]fwrite failed.", __func__, FILE_NAME, __LINE__);
+      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    }
+  }
+  
+  stack[0].ival = write_length;
   
   return 0;
 }
@@ -332,7 +353,7 @@ int32_t SPVM__Sys__IO__fclose(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = fclose(stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]fclose failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fclose failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -364,7 +385,7 @@ int32_t SPVM__Sys__IO__fseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = fseek(stream, offset, whence);
   if (status == -1) {
-    env->die(env, stack, "[System Error]fseek failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fseek failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -385,7 +406,7 @@ int32_t SPVM__Sys__IO__ftell(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t offset = ftell(stream);
   if (offset == -1) {
-    env->die(env, stack, "[System Error]ftell failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]ftell failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -406,7 +427,7 @@ int32_t SPVM__Sys__IO__fflush(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = fflush(stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]fflush failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fflush failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -440,7 +461,7 @@ int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   FILE* reopened_stream = freopen(path, mode, stream);
   
   if (!reopened_stream) {
-    env->die(env, stack, "[System Error]freopen failed:%s. The \"%s\" file can't be reopend", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]freopen failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -480,7 +501,7 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = setvbuf(stream, buf, mode, size);
   if (!(status == 0)) {
-    env->die(env, stack, "[System Error]setvbuf failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]setvbuf failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -489,24 +510,6 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
-#if defined(_WIN32)
-  return env->die(env, stack, "fsync is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
-#else
-  int32_t fd = stack[0].ival;
-  
-  int32_t status = fsync(fd);
-  if (status == -1) {
-    env->die(env, stack, "[System Error]fsync failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-#endif
-}
-
 int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
@@ -523,7 +526,7 @@ int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = open(path, flags, mode);
   if (fd == -1) {
-    env->die(env, stack, "[System Error]open failed:%s. The \"%s\" file can't be opend", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]open failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -557,7 +560,7 @@ int32_t SPVM__Sys__IO__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t read_length = read(fd, buf + buf_offset, count);
   if (read_length == -1) {
-    env->die(env, stack, "[System Error]read failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]read failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -598,7 +601,7 @@ int32_t SPVM__Sys__IO__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t write_length = write(fd, buf + buf_offset, count);
   if (write_length == -1) {
-    env->die(env, stack, "[System Error]write failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]write failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -616,12 +619,12 @@ int32_t SPVM__Sys__IO__lseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!(offset >= 0)) {
     return env->die(env, stack, "$offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
-
+  
   int32_t whence = stack[2].ival;
-
+  
   int64_t cur_offset = lseek(fd, offset, whence);
   if (cur_offset == -1) {
-    env->die(env, stack, "[System Error]lseek failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]lseek failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -634,10 +637,88 @@ int32_t SPVM__Sys__IO__lseek(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__close(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
-
+  
   int32_t status = close(fd);
   if (status == -1) {
-    env->die(env, stack, "[System Error]close failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]close failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(_WIN32)
+  return env->die(env, stack, "fsync is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+#else
+  int32_t fd = stack[0].ival;
+  
+  int32_t status = fsync(fd);
+  if (status == -1) {
+    env->die(env, stack, "[System Error]fsync failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(_WIN32)
+  return env->die(env, stack, "fcntl is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+#else
+  
+  int32_t error_id = 0;
+  
+  int32_t fd = stack[0].ival;
+  
+  int32_t command = stack[1].ival;
+  
+  int32_t ret = -1;
+  
+  void* obj_command_arg = stack[2].oval;
+  
+  if (!obj_command_arg) {
+    ret = fcntl(fd, command, NULL);
+  }
+  else {
+    int32_t command_arg_basic_type_id = env->get_object_basic_type_id(env, stack, obj_command_arg);
+    int32_t command_arg_type_dimension = env->get_object_type_dimension(env, stack, obj_command_arg);
+    
+    // Int
+    if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && command_arg_type_dimension == 0) {
+      int32_t value = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
+      ret = fcntl(fd, command, value);
+    }
+    else if (env->is_type_by_name(env, stack, obj_command_arg, "Sys::IO::Flock", 0)) {
+      struct flock* st_flock = env->get_pointer(env, stack, obj_command_arg);
+      ret = fcntl(fd, command, st_flock);
+    }
+    else {
+      return env->die(env, stack, "$command_arg must be an instance of the Int class or Sys::IO::Flock class.", __func__, FILE_NAME, __LINE__);
+    }
+  }
+  
+  stack[0].ival = ret;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO__ftruncate(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t fd = stack[0].ival;
+  
+  int64_t length = stack[1].lval;
+  
+  int32_t status = ftruncate(fd, length);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]ftruncate failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -658,7 +739,7 @@ int32_t SPVM__Sys__IO__flock(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = flock(fd, operation);
   if (status == -1) {
-    env->die(env, stack, "[System Error]flock failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]flock failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -668,6 +749,86 @@ int32_t SPVM__Sys__IO__flock(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
+int32_t SPVM__Sys__IO__access(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+  void* obj_pathname = stack[0].oval;
+  
+  if (!obj_pathname) {
+    return env->die(env, stack, "$pathname must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const char* pathname = env->get_chars(env, stack, obj_pathname);
+  
+  int32_t mode = stack[1].ival;
+  
+  int32_t status = access(pathname, mode);
+  
+  if (status == -1) {
+    const char* pathname = env->get_chars(env, stack, obj_pathname);
+    env->die(env, stack, "[System Error]access failed:%s.", env->strerror(env, stack, errno, 0), pathname, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__IO__faccessat(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+#if defined(_WIN32)
+  return env->die(env, stack, "faccessat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+#else
+  int32_t dirfd = stack[0].ival;
+  
+  void* obj_pathname = stack[1].oval;
+  if (!obj_pathname) {
+    return env->die(env, stack, "$pathname must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* pathname = env->get_chars(env, stack, obj_pathname);
+  
+  int32_t mode = stack[2].ival;
+  
+  int32_t flags = stack[3].ival;
+  
+  int32_t status = faccessat(dirfd, pathname, mode, flags);
+  
+  if (status == -1) {
+    const char* pathname = env->get_chars(env, stack, obj_pathname);
+    env->die(env, stack, "[System Error]faccessat failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO__truncate(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_path = stack[0].oval;
+  if (!obj_path) {
+    return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* path = env->get_chars(env, stack, obj_path);
+  
+  int64_t length = stack[1].lval;
+  if (!(length >= 0)) {
+    return env->die(env, stack, "$length must be less than or equal to 0.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  int32_t status = truncate(path, length);
+  if (status == -1) {
+    env->die(env, stack, "[System Error]truncate failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
@@ -681,13 +842,13 @@ int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t mode = stack[1].ival;
   
 #if defined(_WIN32)
-  int32_t status = mkdir(path);
+  int32_t status = _mkdir(path);
 #else
   int32_t status = mkdir(path, mode);
 #endif
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]mkdir failed:%s. The \"%s\" directory can't be created", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]mkdir failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -719,7 +880,7 @@ int32_t SPVM__Sys__IO__rmdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = rmdir(path);
   if (status == -1) {
-    env->die(env, stack, "[System Error]rmdir failed:%s. The \"%s\" directory can't be removed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]rmdir failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -740,7 +901,7 @@ int32_t SPVM__Sys__IO__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = unlink(pathname);
   if (status == -1) {
-    env->die(env, stack, "[System Error]unlink failed:%s. The \"%s\" file can't be removed", env->strerror(env, stack, errno, 0), pathname, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]unlink failed:%s. $pathname is \"%s\".", env->strerror(env, stack, errno, 0), pathname, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -771,7 +932,7 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = rename(oldpath, newpath);
   if (status == -1) {
-    env->die(env, stack, "[System Error]rename failed:%s. The \"%s\" file can't be renamed to the \"%s\" file", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]rename failed:%s. $oldpath is \"%s\". $newpath is \"%s\".", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -785,9 +946,9 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
   
   void* obj_buf = stack[0].oval;
-
+  
   int32_t size = stack[1].ival;
-
+  
   if (!(size >= 0)) {
     return env->die(env, stack, "$size must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
@@ -811,7 +972,7 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_buf) {
-    env->die(env, stack, "[System Error]getcwd failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getcwd failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -830,9 +991,9 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t drive = stack[0].ival;
   
   void* obj_buffer = stack[1].oval;
-
+  
   int32_t maxlen = stack[2].ival;
-
+  
   if (!(maxlen > 0)) {
     return env->die(env, stack, "$maxlen must be greater than 0.", __func__, FILE_NAME, __LINE__);
   }
@@ -856,7 +1017,7 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_buffer) {
-    env->die(env, stack, "[System Error]_getdcwd failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]_getdcwd failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -896,7 +1057,7 @@ int32_t SPVM__Sys__IO__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_resolved_path) {
-    env->die(env, stack, "[System Error]realpath failed:%s. The \"%s\" file can't be resolved", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]realpath failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -937,7 +1098,7 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_absPath) {
-    env->die(env, stack, "[System Error]_fullpath failed:%s. The \"%s\" file can't be resolved", env->strerror(env, stack, errno, 0), relPath, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]_fullpath failed:%s. $relPath is \"%s\".", env->strerror(env, stack, errno, 0), relPath, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -957,7 +1118,7 @@ int32_t SPVM__Sys__IO__chdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = chdir(path);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chdir failed:%s. The current directory can't be changed to the \"%s\" directory", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chdir failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -978,7 +1139,7 @@ int32_t SPVM__Sys__IO__chmod(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = chmod(path, mode);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chmod failed:%s. The permission of the \"%s\" file can't be changed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chmod failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1005,7 +1166,7 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = chown(path, owner, group);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chown failed:%s. The owner/group of the \"%s\" file can't be changed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chown failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1015,30 +1176,6 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__IO__truncate(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* obj_path = stack[0].oval;
-  if (!obj_path) {
-    return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  const char* path = env->get_chars(env, stack, obj_path);
-  
-  int64_t length = stack[1].lval;
-  if (!(length >= 0)) {
-    return env->die(env, stack, "$length must be less than or equal to 0.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  int32_t status = truncate(path, length);
-  if (status == -1) {
-    env->die(env, stack, "[System Error]truncate failed:%s. The \"%s\" file can't be truncated", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__symlink(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
   env->die(env, stack, "symlink is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
@@ -1060,7 +1197,7 @@ int32_t SPVM__Sys__IO__symlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = symlink(oldpath, newpath);
   if (status == -1) {
-    env->die(env, stack, "[System Error]symlink failed:%s. The symbolic link from \"%s\" to \"%s\" can't be created", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]symlink failed:%s. $oldpath is \"%s\". $newpath is \"%s\"", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1100,7 +1237,7 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t placed_length = readlink(path, buf, bufsiz);
   if (placed_length == -1) {
-    env->die(env, stack, "[System Error]readlink failed:%s. The reading of the symbolic link of the \"%s\" file failed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]readlink failed:%s. $path is \"%s\".", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1110,126 +1247,6 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__IO__access(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  void* obj_pathname = stack[0].oval;
-  
-  if (!obj_pathname) {
-    return env->die(env, stack, "$pathname must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  const char* pathname = env->get_chars(env, stack, obj_pathname);
-  
-  int32_t mode = stack[1].ival;
-  
-  int32_t status = access(pathname, mode);
-  
-  if (status == -1) {
-    const char* pathname = env->get_chars(env, stack, obj_pathname);
-    env->die(env, stack, "[System Error]access failed:%s", env->strerror(env, stack, errno, 0), pathname, __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__IO__faccessat(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-#if defined(_WIN32)
-  return env->die(env, stack, "faccessat is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
-#else
-  int32_t dirfd = stack[0].ival;
-  
-  void* obj_pathname = stack[1].oval;
-  if (!obj_pathname) {
-    return env->die(env, stack, "$pathname must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  const char* pathname = env->get_chars(env, stack, obj_pathname);
-  
-  int32_t mode = stack[2].ival;
-  
-  int32_t flags = stack[3].ival;
-  
-  int32_t status = faccessat(dirfd, pathname, mode, flags);
-  
-  if (status == -1) {
-    const char* pathname = env->get_chars(env, stack, obj_pathname);
-    env->die(env, stack, "[System Error]faccessat failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-#endif
-}
-
-int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
-#if defined(_WIN32)
-  return env->die(env, stack, "fcntl is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
-#else
-  
-  int32_t error_id = 0;
-  
-  int32_t fd = stack[0].ival;
-  
-  int32_t command = stack[1].ival;
-  
-  int32_t ret = -1;
-  
-  void* obj_command_arg = stack[2].oval;
-    
-  if (!obj_command_arg) {
-    ret = fcntl(fd, command, NULL);
-  }
-  else {
-    int32_t command_arg_basic_type_id = env->get_object_basic_type_id(env, stack, obj_command_arg);
-    int32_t command_arg_type_dimension = env->get_object_type_dimension(env, stack, obj_command_arg);
-    
-    // Int
-    if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && command_arg_type_dimension == 0) {
-      int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
-      
-      if (error_id) { return error_id; }
-      
-      ret = fcntl(fd, command, command_arg_int32);
-    }
-    // A pointer class
-    else if (env->is_pointer_class(env, stack, obj_command_arg)) {
-      void* command_arg = env->get_pointer(env, stack, obj_command_arg);
-      ret = fcntl(fd, command, command_arg);
-    }
-    else {
-      return env->die(env, stack, "$command_arg must be an Int object or the object that is a pointer class.", __func__, FILE_NAME, __LINE__);
-    }
-  }
-  
-  stack[0].ival = ret;
-  
-  return 0;
-#endif
-}
-
-int32_t SPVM__Sys__IO__ftruncate(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t fd = stack[0].ival;
-  
-  int64_t length = stack[1].lval;
-  
-  int32_t status = ftruncate(fd, length);
-  
-  if (status == -1) {
-    env->die(env, stack, "[System Error]ftruncate failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
@@ -1242,7 +1259,7 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   DIR* dir_stream = opendir(dir);
   if (!dir_stream) {
-    env->die(env, stack, "[System Error]opendir failed:%s. The \"%s\" directory can't be opened", env->strerror(env, stack, errno, 0), dir, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]opendir failed:%s. $dir is \"%s\".", env->strerror(env, stack, errno, 0), dir, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1260,13 +1277,13 @@ int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirp = stack[0].oval;
   if (!obj_dirp) {
-    return env->die(env, stack, "$dirp object must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$dirp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
   int32_t status = closedir(dirp);
   if (status == -1) {
-    env->die(env, stack, "[System Error]closedir failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]closedir failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1291,7 +1308,7 @@ int32_t SPVM__Sys__IO__readdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   errno = 0;
   struct dirent* dirent = readdir(dirp);
   if (errno != 0) {
-    env->die(env, stack, "[System Error]readdir failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]readdir failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1332,7 +1349,7 @@ int32_t SPVM__Sys__IO__telldir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t offset = telldir(dirp);
   if (offset == -1) {
-    env->die(env, stack, "[System Error]telldir failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]telldir failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -1392,7 +1409,7 @@ int32_t SPVM__Sys__IO__popen(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_destroy", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  env->set_field_byte_by_name(env, stack, obj_stream, "is_pipe", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
@@ -1431,7 +1448,7 @@ int32_t SPVM__Sys__IO___popen(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_destroy", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  env->set_field_byte_by_name(env, stack, obj_stream, "is_pipe", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
