@@ -18,17 +18,6 @@ int32_t SPVM__Sys__IO__Dirent__d_ino(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__IO__Dirent__d_reclen(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* obj_dirent = stack[0].oval;
-  
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
-  
-  stack[0].ival = st_dirent->d_reclen;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__Dirent__d_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirent = stack[0].oval;
@@ -45,9 +34,27 @@ int32_t SPVM__Sys__IO__Dirent__d_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-/* Mac doesn't have d_off. Windows doesn't have d_type, d_off
+int32_t SPVM__Sys__IO__Dirent__d_reclen(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(__CYGWIN__)
+  env->die(env, stack, "d_reclen is not supported in this system(defined(__CYGWIN__)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  
+  void* obj_dirent = stack[0].oval;
+  
+  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  
+  stack[0].ival = st_dirent->d_reclen;
+  
+  return 0;
+#endif
+}
 
 int32_t SPVM__Sys__IO__Dirent__d_type(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(_WIN32)
+  env->die(env, stack, "d_type is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
   
   void* obj_dirent = stack[0].oval;
   
@@ -56,10 +63,20 @@ int32_t SPVM__Sys__IO__Dirent__d_type(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = st_dirent->d_type;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__IO__Dirent__d_off(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#if defined(_WIN32)
+  env->die(env, stack, "d_off is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#elif defined(__CYGWIN__)
+  env->die(env, stack, "d_off is not supported in this system(defined(__CYGWIN__)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#elif defined(__APPLE__)
+  env->die(env, stack, "d_off is not supported in this system(defined(__APPLE__)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
   void* obj_dirent = stack[0].oval;
   
   struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
@@ -67,6 +84,5 @@ int32_t SPVM__Sys__IO__Dirent__d_off(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].lval = st_dirent->d_off;
   
   return 0;
+#endif
 }
-
-*/
