@@ -17,25 +17,6 @@
 
 static const char* FILE_NAME = "Sys/Socket.c";
 
-int32_t SPVM__Sys__Socket__socket_errno(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t ret_socket_errno = spvm_socket_errno();
-  
-  stack[0].ival = ret_socket_errno;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t error_number = stack[0].ival;
-  int32_t length = stack[1].ival;
-  
-  void* obj_socket_strerror = spvm_socket_strerror_string(env, stack, error_number, length);
-  
-  stack[0].oval = obj_socket_strerror;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__Socket__htonl(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t hostlong = stack[0].ival;
@@ -81,7 +62,7 @@ int32_t SPVM__Sys__Socket__ntohs(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
-
+  
   int32_t error_id = 0;
   
   int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &error_id, __func__, FILE_NAME, __LINE__);
@@ -114,7 +95,7 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
-    env->die(env, stack, "[System Error]inet_aton failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_aton failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -134,9 +115,9 @@ int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
   struct in_addr* in = env->get_pointer(env, stack, obj_in);
   
   char* output_address = inet_ntoa(*in);
-
+  
   if (!output_address) {
-    env->die(env, stack, "[System Error]inet_ntoa failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_ntoa failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -159,13 +140,13 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t InvalidNetworkAddress = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
-
+  
   int32_t In_addr = env->get_basic_type_id(env, stack, "Sys::Socket::In_addr");
   if (error_id) { return error_id; }
-
+  
   int32_t In6_addr = env->get_basic_type_id(env, stack, "Sys::Socket::In6_addr");
   if (error_id) { return error_id; }
-
+  
   int32_t af = stack[0].ival;
   
   if (!(af == AF_INET || af == AF_INET6)) {
@@ -209,7 +190,7 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
     return InvalidNetworkAddress;
   }
   else if (status == -1) {
-    env->die(env, stack, "[System Error]inet_pton failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_pton failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -219,10 +200,10 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
-
+  
   // The address family
   int32_t af = stack[0].ival;
-
+  
   if (!(af == AF_INET || af == AF_INET6)) {
     return env->die(env, stack, "$af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
@@ -247,7 +228,7 @@ int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* dst_ret = inet_ntop(af, src, dst, size);
   
   if (!dst_ret) {
-    env->die(env, stack, "[System Error]inet_ntop failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]inet_ntop failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -267,7 +248,7 @@ int32_t SPVM__Sys__Socket__socket(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t sockfd = socket(domain, type, protocol);
   
   if (sockfd == -1) {
-    env->die(env, stack, "[System Error]socket failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]socket failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -276,7 +257,6 @@ int32_t SPVM__Sys__Socket__socket(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-
 int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t sockfd = stack[0].ival;
@@ -294,7 +274,7 @@ int32_t SPVM__Sys__Socket__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = connect(sockfd, addr, addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]connect failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]connect failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -320,7 +300,7 @@ int32_t SPVM__Sys__Socket__bind(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = bind(sockfd, addr, addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]bind failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]bind failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -348,7 +328,7 @@ int32_t SPVM__Sys__Socket__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = accept(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]accept failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]accept failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -368,7 +348,7 @@ int32_t SPVM__Sys__Socket__listen(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = listen(sockfd, backlog);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]listen failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]listen failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -377,10 +357,48 @@ int32_t SPVM__Sys__Socket__listen(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
-
+int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
   int32_t sockfd = stack[0].ival;
+  
+  int32_t how = stack[1].ival;
+  
+  int32_t status = shutdown(sockfd, how);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]shutdown failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
 
+int32_t SPVM__Sys__Socket__closesocket(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if !defined(_WIN32)
+  env->die(env, stack, "[Not Supported]closesocket is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  int32_t s = stack[0].ival;
+  
+  int32_t status = closesocket(s);
+  
+  if (!(status == 0)) {
+    env->die(env, stack, "[System Error]close failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t sockfd = stack[0].ival;
+  
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
@@ -402,7 +420,7 @@ int32_t SPVM__Sys__Socket__recv(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t bytes_length = recv(sockfd, buf + buf_offset, len, flags);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]recv failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]recv failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -436,7 +454,7 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t bytes_length = send(sockfd, buf + buf_offset, len, flags);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]send failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]send failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -480,7 +498,7 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t bytes_length = sendto(sockfd, buf + buf_offset, len, flags, addr, addrlen);
   
   if (bytes_length == -1) {
-    env->die(env, stack, "[System Error]sendto failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]sendto failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -508,7 +526,7 @@ int32_t SPVM__Sys__Socket__getpeername(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = getpeername(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]getpeername failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getpeername failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -538,7 +556,7 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = getsockname(sockfd, addr, &sl_addrlen);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]getsockname failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getsockname failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -549,6 +567,81 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t sockfd = stack[0].ival;
+  
+  int32_t level = stack[1].ival;
+  
+  int32_t optname = stack[2].ival;
+  
+  void* obj_optval = stack[3].oval;
+  char* optval = NULL;
+  if (!obj_optval) {
+    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  optval = (char*)env->get_chars(env, stack, obj_optval);
+  int32_t optval_length = env->length(env, stack, obj_optval);
+  
+  int32_t* optlen_ref = stack[4].iref;
+  if (!(*optlen_ref >= 0)) {
+    env->die(env, stack, "The referred value of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+  }
+  if (!(*optlen_ref <= optval_length)) {
+    env->die(env, stack, "The referred value of $optlen_ref must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  socklen_t socklen_t_optlen = *optlen_ref;
+  int32_t status = getsockopt(sockfd, level, optname, optval, &socklen_t_optlen);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]getsockopt failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  *optlen_ref = socklen_t_optlen;
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t sockfd = stack[0].ival;
+  
+  int32_t level = stack[1].ival;
+  
+  int32_t optname = stack[2].ival;
+  
+  void* obj_optval = stack[3].oval;
+  char* optval = NULL;
+  if (!obj_optval) {
+    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  optval = (char*)env->get_chars(env, stack, obj_optval);
+  int32_t optval_length = env->length(env, stack, obj_optval);
+  
+  socklen_t optlen = stack[4].ival;
+  if (!(optlen >= 0)) {
+    env->die(env, stack, "$optlen must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+  }
+  if (!(optlen <= optval_length)) {
+    env->die(env, stack, "$optlen must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  int32_t status = setsockopt(sockfd, level, optname, optval, optlen);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]setsockopt failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
   env->die(env, stack, "socketpair is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
@@ -556,11 +649,11 @@ int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
 #else
   
   int32_t domain = stack[0].ival;
-
+  
   int32_t type = stack[1].ival;
-
+  
   int32_t protocol = stack[2].ival;
-
+  
   void* obj_sv = stack[3].oval;
   
   if (!obj_sv) {
@@ -570,15 +663,15 @@ int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* sv = env->get_elems_int(env, stack, obj_sv);
   int32_t sv_length = env->length(env, stack, obj_sv);
   
-  if (!(sv_length >= 2)) {
-    return env->die(env, stack, "The length of $sv must be greater than or equal to 2.", __func__, FILE_NAME, __LINE__);
+  if (!(sv_length == 2)) {
+    return env->die(env, stack, "The length of $sv must be equal to 2.", __func__, FILE_NAME, __LINE__);
   }
   
   int int_sv[2];
   int32_t status = socketpair(domain, type, protocol, int_sv);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]socketpair failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]socketpair failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -591,180 +684,7 @@ int32_t SPVM__Sys__Socket__socketpair(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t sockfd = stack[0].ival;
-
-  int32_t level = stack[1].ival;
-
-  int32_t optname = stack[2].ival;
-
-  void* obj_optval = stack[3].oval;
-  char* optval = NULL;
-  if (!obj_optval) {
-    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  optval = (char*)env->get_chars(env, stack, obj_optval);
-  int32_t optval_length = env->length(env, stack, obj_optval);
-
-  socklen_t optlen = stack[4].ival;
-  if (!(optlen >= 0)) {
-    env->die(env, stack, "$optlen must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
-  }
-  if (!(optlen <= optval_length)) {
-    env->die(env, stack, "$optlen must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  int32_t status = setsockopt(sockfd, level, optname, optval, optlen);
-  
-  if (status == -1) {
-    env->die(env, stack, "[System Error]setsockopt failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__setsockopt_int(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t int32_optval = stack[3].ival;
-  
-  int int_optval = int32_optval;
-  
-  void* obj_optval = env->new_string(env, stack, NULL, sizeof(int));
-  char* optval = (char*)env->get_chars(env, stack, obj_optval);
-  memcpy(optval, &int_optval, sizeof(int));
-  
-  stack[3].oval = obj_optval;
-
-  stack[4].ival = sizeof(int);
-  
-  return SPVM__Sys__Socket__setsockopt(env, stack);
-}
-
-int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t sockfd = stack[0].ival;
-
-  int32_t level = stack[1].ival;
-
-  int32_t optname = stack[2].ival;
-  
-  void* obj_optval = stack[3].oval;
-  char* optval = NULL;
-  if (!obj_optval) {
-    return env->die(env, stack, "$optval must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  optval = (char*)env->get_chars(env, stack, obj_optval);
-  int32_t optval_length = env->length(env, stack, obj_optval);
-
-  int32_t* optlen_ref = stack[4].iref;
-  if (!(*optlen_ref >= 0)) {
-    env->die(env, stack, "The referred value of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
-  }
-  if (!(*optlen_ref <= optval_length)) {
-    env->die(env, stack, "The referred value of $optlen_ref must be less than or equal to the length of $optval.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  socklen_t socklen_t_optlen = *optlen_ref;
-  int32_t status = getsockopt(sockfd, level, optname, optval, &socklen_t_optlen);
-  
-  if (status == -1) {
-    env->die(env, stack, "[System Error]getsockopt failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  *optlen_ref = socklen_t_optlen;
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-
-int32_t SPVM__Sys__Socket__getsockopt_int(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t* int32_optval_ref = stack[3].iref;
-  
-  int32_t int32_optval = *int32_optval_ref;
-  
-  int int_optval = int32_optval;
-  
-  void* obj_optval = env->new_string(env, stack, NULL, sizeof(int));
-  char* optval = (char*)env->get_chars(env, stack, obj_optval);
-  memcpy(optval, &int_optval, sizeof(int));
-  
-  stack[3].oval = obj_optval;
-  
-  int32_t optlen = sizeof(int);
-  stack[4].iref = &optlen;
-  
-  int32_t status = SPVM__Sys__Socket__getsockopt(env, stack);
-  
-  *int32_optval_ref = *(int*)optval;
-  
-  return status;
-}
-
-int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t sockfd = stack[0].ival;
-  
-  int32_t how = stack[1].ival;
-  
-  int32_t status = shutdown(sockfd, how);
-  
-  if (status == -1) {
-    env->die(env, stack, "[System Error]shutdown failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__closesocket(SPVM_ENV* env, SPVM_VALUE* stack) {
-#if !defined(_WIN32)
-  env->die(env, stack, "[Not Supported]closesocket is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
-#else
-  int32_t s = stack[0].ival;
-  
-  int32_t status = closesocket(s);
-  
-  if (!(status == 0)) {
-    env->die(env, stack, "[System Error]close failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  stack[0].ival = status;
-  
-  return 0;
-#endif
-}
-
-int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
-  
-  int32_t errcode = stack[0].ival;
-  
-  const char* error_string = gai_strerror(errcode);
-  
-  if (error_string) {
-    int32_t error_string_length = strlen(error_string);
-    void* obj_error_string = env->new_string(env, stack, error_string, error_string_length);
-    stack[0].oval = obj_error_string;
-  }
-  else {
-    stack[0].oval = NULL;
-  }
-  
-  return 0;
-}
+int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack);
 
 int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
@@ -795,8 +715,8 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$res_array must be defined.", __func__, FILE_NAME, __LINE__);
   }
   int32_t res_array_length = env->length(env, stack, obj_res_array);
-  if (!(res_array_length >= 1)) {
-    return env->die(env, stack, "The length of $res_array must be greater than or equal to 1.", __func__, FILE_NAME, __LINE__);
+  if (!(res_array_length == 1)) {
+    return env->die(env, stack, "The length of $res_array must be equal to 1.", __func__, FILE_NAME, __LINE__);
   }
   
   struct addrinfo *res = NULL;
@@ -814,7 +734,7 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM__Sys__Socket__gai_strerror(env, stack);
     void* obj_gai_strerror = stack[0].oval;
     const char* ch_gai_strerror = env->get_chars(env, stack, obj_gai_strerror);
-    env->die(env, stack, "[System Error]getaddrinfo failed: %s", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getaddrinfo failed: %s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -834,7 +754,7 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const struct sockaddr* sa = env->get_pointer(env, stack, obj_sa);
-
+  
   int32_t salen = stack[1].ival;
   
   void* obj_host = stack[2].oval;
@@ -852,7 +772,7 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   int32_t servlen = stack[5].ival;
-
+  
   int32_t flags = stack[6].ival;
   
   int32_t status = getnameinfo(sa, salen, host, hostlen, serv, servlen, flags);
@@ -862,7 +782,7 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM__Sys__Socket__gai_strerror(env, stack);
     void* obj_gai_strerror = stack[0].oval;
     const char* ch_gai_strerror = env->get_chars(env, stack, obj_gai_strerror);
-    env->die(env, stack, "[System Error]getnameinfo failed: %s", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getnameinfo failed: %s.", ch_gai_strerror, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -871,6 +791,25 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__Socket__gai_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t errcode = stack[0].ival;
+  
+  const char* error_string = gai_strerror(errcode);
+  
+  if (error_string) {
+    int32_t error_string_length = strlen(error_string);
+    void* obj_error_string = env->new_string(env, stack, error_string, error_string_length);
+    stack[0].oval = obj_error_string;
+  }
+  else {
+    env->die(env, stack, "[System Error]gai_strerror failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
     env->die(env, stack, "[Not Supported]sockatmark is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
@@ -882,7 +821,7 @@ int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = sockatmark(sockfd);
   
   if (status == -1) {
-    env->die(env, stack, "[System Error]shutdown failed: %s", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]sockatmark failed: %s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -892,56 +831,3 @@ int32_t SPVM__Sys__Socket__sockatmark(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__Socket__to_family_sockaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t error_id = 0;
-  
-  void* obj_addr = stack[0].oval;
-  
-  if (!obj_addr) {
-    return env->die(env, stack, "$addr must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
-  
-  int32_t sa_family = addr->sa_family;
-  
-  void* obj_addr_child = NULL;
-  
-  switch (sa_family) {
-    case AF_INET: {
-      struct sockaddr_in* addr_in = env->new_memory_block(env, stack, sizeof(struct sockaddr_in));
-      memcpy(addr_in, addr, sizeof(struct sockaddr_in));
-      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In", addr_in, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
-      
-      break;
-    }
-    case AF_INET6: {
-      struct sockaddr_in6* addr_in6 = env->new_memory_block(env, stack, sizeof(struct sockaddr_in6));
-      memcpy(addr_in6, addr, sizeof(struct sockaddr_in6));
-      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In6", addr_in6, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
-      
-      break;
-    }
-    case AF_UNIX: {
-#if defined(_WIN32)
-      env->die(env, stack, "AF_UNIX is not supported in this system(defined(_WIN32))", sa_family, __func__, FILE_NAME, __LINE__);
-      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
-#else
-      struct sockaddr_un* addr_un = env->new_memory_block(env, stack, sizeof(struct sockaddr_un));
-      memcpy(addr_un, addr, sizeof(struct sockaddr_un));
-      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::Un", addr_un, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
-#endif
-      break;
-    }
-    default: {
-      return env->die(env, stack, "The address family %d is not available.", sa_family, __func__, FILE_NAME, __LINE__);
-    }
-  }
-  
-  stack[0].oval = obj_addr_child;
-  
-  return 0;
-}
